@@ -3,8 +3,16 @@ from scipy.integrate import cumtrapz
 from scipy.interpolate import interp1d
 
 class Sampler:
-    """Class for generating random samples from given `rate` """
+    """ Generates random event samples (timestamps) following the given event rate"""
     def __init__(self,r, time_window=[0,10], Npoints=1000):
+        """
+        Args:
+            r (rate): event rate
+            time_window (tuple[float,float]): limits in which the events are generated
+            Npoints (int): number of subdivisions for the integration.
+                The initial distribution is approximated by `Npoints` 
+                equidistant points in the `time_window` range
+        """
         x = np.linspace(*time_window,Npoints)
         y = r(x)
         self._set(x,y)
@@ -22,6 +30,11 @@ class Sampler:
         self.Ytotal = Ytotal
         
     def sample(self):
+        """ Produce the random events
+
+        Returns:
+            ndarray: 1-d array with the events timestamps
+        """
         Ntot = np.random.poisson(self.Ytotal)
         ps = np.random.rand(Ntot)
         return self.x_of_p(ps)
